jsonEncodeInt function

dynamic jsonEncodeInt(
  1. int value
)

Converts an int to a dynamic value for JSON encoding.

final jsonValue = intToJson(42);
print(jsonValue); // 42

@ai Use this method for encoding int values into JSON format.

Implementation

dynamic jsonEncodeInt(final int value) => value;