jsonDecodeDouble function
Converts a dynamic value to a double.
Returns 0 if the input is null or cannot be converted to a double.
doubleFromJson('3.14'); // 3.14
@ai Use this method when you need a default value for null inputs.
Implementation
double jsonDecodeDouble(final dynamic value) =>
jsonDecodeNullableDouble(value) ?? 0;