jsonDecodeInt function
Converts a dynamic value to an int.
Returns 0 if the input is null or cannot be converted to an int.
jsonDecodeInt('42'); // 42
@ai Use this method when you need a default value for null inputs.
Implementation
int jsonDecodeInt(final dynamic value) => jsonDecodeNullableInt(value) ?? 0;